@@ -28,6 +28,7 @@
 #include <QRandomGenerator>
 #include "StelTextureTypes.hpp"
 #include "StelModule.hpp"
+#include "StelUtils.hpp"
 #include "VecMath.hpp"
 
 // Predeclaration of some classes
@@ -87,6 +88,7 @@ class StelApp : public QObject
 	Q_PROPERTY(Vec3f daylightInfoColor	READ getDaylightInfoColor	WRITE setDaylightInfoColor	 NOTIFY daylightInfoColorChanged)
 	Q_PROPERTY(int  screenFontSize          READ getScreenFontSize          WRITE setScreenFontSize          NOTIFY screenFontSizeChanged)
 	Q_PROPERTY(int  guiFontSize             READ getGuiFontSize             WRITE setGuiFontSize             NOTIFY guiFontSizeChanged)
+	Q_PROPERTY(double screenButtonScale     READ getScreenButtonScale       WRITE setScreenButtonScale       NOTIFY screenButtonScaleChanged)
 	Q_PROPERTY(bool flagImmediateSave       READ getFlagImmediateSave       WRITE setFlagImmediateSave       NOTIFY flagImmediateSaveChanged)
 
 	Q_PROPERTY(QString version READ getVersion CONSTANT)
@@ -215,11 +217,23 @@ public:
 	int getScreenFontSize() const { return screenFontSize; }
 	//! Change screen font size.
 	void setScreenFontSize(int s);
+	//! Get the ratio of current font size used for screen text to the default value
+	double screenFontSizeRatio() const;
+	//! Get the ratio of current font size used for GUI to the default value
+	double guiFontSizeRatio() const { return double(getGuiFontSize()) / getDefaultGuiFontSize(); }
 	//! Get the principal font size used for GUI panels.
 	int getGuiFontSize() const;
 	//! change GUI font size.
 	void setGuiFontSize(int s);
 
+	//! Get the ratio (in percent) of screen button size to the default screen scale-dependent one
+	double getScreenButtonScale() const { return screenButtonScale; }
+	//! Set the ratio (in percent) of screen button size to the default screen scale-dependent one
+	void setScreenButtonScale(double s);
+
+	//! Combines #getDevicePixelsPerPixel and #getScreenFontSize
+	float getScreenScale() const;
+
 	//! Get the GUI instance implementing the abstract GUI interface.
 	StelGuiBase* getGui() const {return stelGui;}
 	//! Tell the StelApp instance which GUI is currently being used.
@@ -263,7 +277,7 @@ public:
 	//! Dump diagnostics about action call priorities
 	void dumpModuleActionPriorities(StelModule::StelModuleActionName actionName) const;
 
-	static constexpr int getDefaultGuiFontSize() { return 13; }
+	static constexpr int getDefaultGuiFontSize() { return DEFAULT_FONT_SIZE; }
 
 	static bool isInitialized() {if (singleton) return singleton->initialized; else return false;}
 	
@@ -366,6 +380,7 @@ signals:
 	void languageChanged();
 	void screenFontSizeChanged(int);
 	void guiFontSizeChanged(int);
+	void screenButtonScaleChanged(double);
 	void fontChanged(const QFont&);
 	void overwriteInfoColorChanged(const Vec3f & color);
 	void daylightInfoColorChanged(const Vec3f & color);
@@ -497,6 +512,7 @@ private:
 
 	QList<StelProgressController*> progressControllers;
 
+	double screenButtonScale = 100; // in percent
 	int screenFontSize;
 	int numMultiSamples = 1;
 
