@@ -26,6 +26,7 @@
 #include "StelLocation.hpp"
 #include "StelSkyDrawer.hpp"
 #include "StelPropertyMgr.hpp"
+#include "SolarSystem.hpp"
 #include "Dithering.hpp"
 #include <QString>
 #include <QStringList>
@@ -55,6 +56,8 @@ class StelCore : public QObject
 	Q_PROPERTY(bool flagUseNutation READ getUseNutation WRITE setUseNutation NOTIFY flagUseNutationChanged)
 	Q_PROPERTY(bool flagUseAberration READ getUseAberration WRITE setUseAberration NOTIFY flagUseAberrationChanged)
 	Q_PROPERTY(double aberrationFactor READ getAberrationFactor WRITE setAberrationFactor NOTIFY aberrationFactorChanged)
+	Q_PROPERTY(bool flagUseParallax READ getUseParallax WRITE setUseParallax NOTIFY flagUseParallaxChanged)
+	Q_PROPERTY(double parallaxFactor READ getParallaxFactor WRITE setParallaxFactor NOTIFY parallaxFactorChanged)
 	Q_PROPERTY(bool flagUseTopocentricCoordinates READ getUseTopocentricCoordinates WRITE setUseTopocentricCoordinates NOTIFY flagUseTopocentricCoordinatesChanged)
 	Q_PROPERTY(ProjectionType currentProjectionType READ getCurrentProjectionType WRITE setCurrentProjectionType NOTIFY currentProjectionTypeChanged)
 	//! This is just another way to access the projection type, by string instead of enum
@@ -247,6 +250,8 @@ public:
 	Vec3d equinoxEquToJ2000(const Vec3d& v, RefractionMode refMode=RefractionAuto) const;
 	//! Use fixed matrix to allow fast transformation of positions related to the IAU constellation borders.
 	Vec3d j2000ToJ1875(const Vec3d& v) const;
+	//! Use fixed matrix to allow fast transformation of positions related to the IAU constellation borders.
+	Vec3d j1875ToJ2000(const Vec3d& v) const;
 	//! Transform position vector v from equatorial coordinates J2000 to those of date (optionally corrected by refraction).
 	//! Use refMode=StelCore::RefractionOff if you don't want any atmosphere correction.
 	//! Use refMode=StelCore::RefractionOn to correct observed (apparent) coordinates (which are subject to refraction).
@@ -374,6 +379,11 @@ public:
 
 	Vec3d getMouseJ2000Pos(void) const;
 
+	//! get vector used to compute parallax effect
+	Vec3d getParallaxDiff(double JD) const;
+	//! get vector used to compute aberration effect
+	Vec3d getAberrationVec(double JD) const;
+
 public slots:
 	//! Smoothly move the observer to the given location
 	//! @param target the target location
@@ -534,27 +544,37 @@ public slots:
 	double getDeltaT() const;
 
 	//! @return whether nutation is currently used.
-	bool getUseNutation() const {return flagUseNutation;}
+	bool getUseNutation() const;
 	//! Set whether you want computation and simulation of nutation (a slight wobble of Earth's axis, just a few arcseconds).
-	void setUseNutation(bool use) { if (flagUseNutation != use) { flagUseNutation=use; StelApp::immediateSave("astro/flag_nutation", use); emit flagUseNutationChanged(use); }}
+	void setUseNutation(bool use);
 
 	//! @return whether aberration is currently used.
-	bool getUseAberration() const {return flagUseAberration;}
+	bool getUseAberration() const;
 	//! Set whether you want computation and simulation of aberration (a slight wobble of stellar positions due to finite speed of light, about 20 arcseconds when observing from earth).
-	void setUseAberration(bool use) { if (flagUseAberration != use) { flagUseAberration=use; StelApp::immediateSave("astro/flag_aberration", use); emit flagUseAberrationChanged(use); }}
+	void setUseAberration(bool use);
 
 	//! @return aberration factor. 1 is realistic simulation, but higher values may be useful for didactic purposes.
-	double getAberrationFactor() const {return aberrationFactor;}
+	double getAberrationFactor() const;
 	//! Set aberration factor. Values are clamped to 0...5. (Values above 5 cause graphical problems.)
-	void setAberrationFactor(double factor) { if (!fuzzyEquals(aberrationFactor, factor)) { aberrationFactor=qBound(0.,factor, 5.); StelApp::immediateSave("astro/aberration_factor", aberrationFactor); emit aberrationFactorChanged(factor); }}
+	void setAberrationFactor(double factor);
 
 	QByteArray getAberrationShader() const;
 	void setAberrationUniforms(QOpenGLShaderProgram& program) const;
 
+	//! @return whether parallax effect is currently used.
+	bool getUseParallax() const;
+	//! Set whether you want computation and simulation of parallax effect.
+	void setUseParallax(bool use);
+
+	//! @return parallax factor. 1 is realistic simulation, but higher values may be useful for didactic purposes.
+	double getParallaxFactor() const;
+	//! Set aberration factor. Values are clamped to 0...5. (Values above 5 cause graphical problems.)
+	void setParallaxFactor(double factor);
+
 	//! @return whether topocentric coordinates are currently used.
-	bool getUseTopocentricCoordinates() const {return flagUseTopocentricCoordinates;}
+	bool getUseTopocentricCoordinates() const;
 	//! Set whether you want topocentric or planetocentric data
-	void setUseTopocentricCoordinates(bool use) { if (flagUseTopocentricCoordinates!= use) { flagUseTopocentricCoordinates=use; StelApp::immediateSave("astro/flag_topocentric_coordinates", use); emit flagUseTopocentricCoordinatesChanged(use); }}
+	void setUseTopocentricCoordinates(bool use);
 
 	//! Return the preset sky time in JD
 	double getPresetSkyTime() const;
@@ -862,6 +882,10 @@ signals:
 	void flagUseAberrationChanged(bool b);
 	//! This signal indicates a change in aberration exaggeration factor
 	void aberrationFactorChanged(double val);
+	//! This signal indicates a switch in use of parallax
+	void flagUseParallaxChanged(bool b);
+	//! This signal indicates a change in parallax exaggeration factor
+	void parallaxFactorChanged(double val);
 	//! This signal indicates a switch in use of topocentric coordinates
 	void flagUseTopocentricCoordinatesChanged(bool b);
 	//! Emitted whenever the projection type changes
@@ -943,6 +967,10 @@ private:
 	bool flagUseAberration;
 	// value to allow exaggerating aberration effects. 1 is natural value, stretching to e.g. 1000 may be useful for explanations.
 	double aberrationFactor;
+	// flag to indicate we want to include parallax effect
+	bool flagUseParallax;
+	// value to allow exaggerating parallax effects. 1 is natural value, stretching to e.g. 1000 may be useful for explanations.
+	double parallaxFactor;
 	// flag to indicate that we show topocentrically corrected coordinates. (Switching to false for planetocentric coordinates is new for 0.14)
 	bool flagUseTopocentricCoordinates;
 
@@ -984,6 +1012,17 @@ private:
 	bool de440Active;    // available and user-activated.
 	bool de441Active;    // available and user-activated.
 	QPair<int, int> minMaxEphemRange;
-};
+	
+	// Variables for caching the observer position relative to the star catalog reference frame
+	static Vec3d cachedParallaxDiff;
+    static double cachedParallaxJD; // Cached Julian Date
+	static PlanetP cachedParallaxPlanet;
+	Vec3d calculateParallaxDiff(double JD) const; // Actual calculation
 
+	// Variables for caching the aberration effect
+	static Vec3d cachedAberrationVec;
+	static double cachedAberrationJD;
+	static PlanetP cachedAberrationPlanet;
+	Vec3d calculateAberrationVec(double JD) const; // Actual calculation
+};
 #endif // STELCORE_HPP
