@@ -315,11 +315,11 @@ float StelObject::getSelectPriority(const StelCore* core) const
 	return qMin(getVMagnitudeWithExtinction(core), 15.0f);
 }
 
-float StelObject::getVMagnitudeWithExtinction(const StelCore* core, const float knownVMag) const
+float StelObject::getVMagnitudeWithExtinction(const StelCore* core, const float knownVMag, const float& magoffset) const
 {
 	Vec3d altAzPos = getAltAzPosGeometric(core);
 	altAzPos.normalize();
-	float vMag = (knownVMag>-1000.f ? knownVMag : getVMagnitude(core));
+	float vMag = (knownVMag>-1000.f ? knownVMag : getVMagnitude(core) + magoffset);
 	// without the test, planets flicker stupidly in fullsky atmosphere-less view.
 	if (core->getSkyDrawer()->getFlagHasAtmosphere())
 		core->getSkyDrawer()->getExtinction().forward(altAzPos, &vMag);
@@ -340,15 +340,16 @@ float StelObject::getAirmass(const StelCore *core) const
 		return -1.f;
 }
 
-// Format the magnitude info string for the object
-QString StelObject::getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals) const
+// Format the magnitude info string for the object, allow offset from changing distance
+QString StelObject::getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals, const float& magoffset) const
 {
 	if (flags&Magnitude)
 	{
-		QString str = QString("%1: <b>%2</b>").arg(q_("Magnitude"), QString::number(getVMagnitude(core), 'f', decimals));
+		float mag = getVMagnitude(core);
+		QString str = QString("%1: <b>%2</b>").arg(q_("Magnitude"), QString::number(getVMagnitude(core) + magoffset, 'f', decimals));
 		const float airmass = getAirmass(core);
 		if (airmass>-1.f) // Don't show extincted magnitude much below horizon where model is meaningless.
-			str += QString(" (%1 <b>%2</b> %3 <b>%4</b> %5)").arg(q_("reduced to"), QString::number(getVMagnitudeWithExtinction(core), 'f', decimals), q_("by"), QString::number(airmass, 'f', 2), q_("Airmasses"));
+			str += QString(" (%1 <b>%2</b> %3 <b>%4</b> %5)").arg(q_("reduced to"), QString::number(getVMagnitudeWithExtinction(core, mag, magoffset), 'f', decimals), q_("by"), QString::number(airmass, 'f', 2), q_("Airmasses"));
 		str += "<br/>" + getExtraInfoStrings(Magnitude).join("");
 		return str;
 	}
@@ -357,10 +358,12 @@ QString StelObject::getMagnitudeInfoString(const StelCore *core, const InfoStrin
 }
 
 // Format the positional info string contain J2000/of date/altaz/hour angle positions for the object
+// computing positional info sometimes also compute others like proper motion too, so store them in the object
 QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGroup& flags) const
 {
 	StelApp& app = StelApp::getInstance();
 	StelObjectMgr* omgr=GETSTELMODULE(StelObjectMgr);
+	const float airmass = getAirmass(core);
 	const StelLocation currentLocation=core->getCurrentLocation();
 	const bool onTransitionToNewLocation=core->getCurrentObserver()->isTraveling();
 	const bool withAtmosphere = core->getSkyDrawer()->getFlagHasAtmosphere();
@@ -370,7 +373,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 	const bool withDesignations = app.getFlagUseCCSDesignation();
 	const QString cepoch = qc_("on date", "coordinates for current epoch");
 	const QString currentPlanet = core->getCurrentPlanet()->getEnglishName();
-	const QString apparent = " " + (withAtmosphere ? q_("(apparent)") : "");
+	const QString apparent = " " + (withAtmosphere && (airmass>-1.f) ? q_("(apparent)") : "");
 	const double currentJD = core->getJD();
 	const double utcShift = core->getUTCOffset(currentJD) / 24.; // Fix DST shift...
 	QString currentObjStr = getEnglishName();
@@ -381,6 +384,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		currentObjStr = StelUtils::radToHmsStr(ra_j2000);
 	}
 
+	const Vec3d eqNow=getEquinoxEquatorialPos(core);
 	QString res, firstCoordinate, secondCoordinate;
 	int currentYear, currentMonth, currentDay;
 	double currentLatitude=static_cast<double>(currentLocation.getLatitude());
@@ -423,7 +427,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 	if (flags&RaDecOfDate)
 	{
 		double dec_equ, ra_equ;
-		StelUtils::rectToSphe(&ra_equ,&dec_equ,getEquinoxEquatorialPos(core));
+		StelUtils::rectToSphe(&ra_equ,&dec_equ,eqNow);
 		if (withDecimalDegree)
 		{
 			firstCoordinate  = StelUtils::radToDecDegStr(ra_equ,5,false,true);
@@ -629,7 +633,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		res += getExtraInfoStrings(EclipticCoordJ2000).join("");
 	}
 
-	if ((flags&EclipticCoordOfDate) && (QString("Earth Sun").contains(currentPlanet)))
+	if ((flags&EclipticCoordOfDate) && (currentPlanet=="Earth"))
 	{
 		const double jde=core->getJDE();
 		double eclJDE = GETSTELMODULE(SolarSystem)->getEarth()->getRotObliquity(jde);
@@ -641,7 +645,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 		}
 		double ra_equ, dec_equ, lambdaJDE, betaJDE;
 
-		StelUtils::rectToSphe(&ra_equ,&dec_equ,getEquinoxEquatorialPos(core));
+		StelUtils::rectToSphe(&ra_equ,&dec_equ,eqNow);
 		StelUtils::equToEcl(ra_equ, dec_equ, eclJDE, &lambdaJDE, &betaJDE);
 		if (lambdaJDE<0) lambdaJDE+=2.0*M_PI;
 		if (withDecimalDegree)
@@ -876,7 +880,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 
 		// Greatest Digression: limiting azimuth and hour angles for stars with upper culmination between pole and zenith
 		double dec_equ, ra_equ;
-		StelUtils::rectToSphe(&ra_equ,&dec_equ,getEquinoxEquatorialPos(core));
+		StelUtils::rectToSphe(&ra_equ,&dec_equ,eqNow);
 		const double latitude=static_cast<double>(core->getCurrentLocation().getLatitude())*M_PI_180;
 		if (((latitude>0.) && (dec_equ>=latitude)) || ((latitude<0.) && (dec_equ<=latitude)))
 		{
@@ -964,7 +968,7 @@ QString StelObject::getCommonInfoString(const StelCore *core, const InfoStringGr
 
 	if (flags&IAUConstellation)
 	{
-		QString constel=core->getIAUConstellation(getEquinoxEquatorialPos(core));
+		QString constel = (fuzzyEquals(eqNow.normSquared(),0.) ? "---" : core->getIAUConstellation(eqNow));
 		res += QString("%1: %2<br/>").arg(q_("IAU Constellation"), constel);
 		res += getExtraInfoStrings(flags&IAUConstellation).join("");
 		res += omgr->getExtraInfoStrings(flags&IAUConstellation).join("");
