@@ -58,6 +58,7 @@ bool Nebula::flagUseArcsecSurfaceBrightness = false;
 bool Nebula::flagUseShortNotationSurfaceBrightness = true;
 bool Nebula::flagUseOutlines = false;
 bool Nebula::flagShowAdditionalNames = true;
+bool Nebula::flagShowOnlyNamedDSO = false;
 bool Nebula::flagUseSizeLimits = false;
 double Nebula::minSizeLimit = 1.0;
 double Nebula::maxSizeLimit = 600.0;
@@ -161,7 +162,7 @@ Nebula::~Nebula()
 {
 }
 
-QString Nebula::getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals) const
+QString Nebula::getMagnitudeInfoString(const StelCore *core, const InfoStringGroup& flags, const int decimals, const float& magOffset) const
 {
 	QString res;
 	const float mmag = qMin(vMag, bMag);
@@ -170,8 +171,8 @@ QString Nebula::getMagnitudeInfoString(const StelCore *core, const InfoStringGro
 		QString emag = "";
 		QString fsys = "";
 		bool bmag = false;
-		float mag = getVMagnitude(core);
-		float mage = getVMagnitudeWithExtinction(core);
+		float mag = getVMagnitude(core) + magOffset;
+		float mage = getVMagnitudeWithExtinction(core, mag, magOffset);
 		bool hasAtmosphere = core->getSkyDrawer()->getFlagHasAtmosphere();
 		QString tmag = q_("Magnitude");
 		if (nType == NebDn || B_nb>0) // Dark nebulae or objects from Barnard catalog
@@ -712,11 +713,10 @@ void Nebula::drawOutlines(StelPainter &sPainter, float maxMagHints) const
 	float oLim = getVisibilityLevelByMagnitude() - 3.f;
 
 	sPainter.setColor(getHintColor(nType), hintsBrightness);
+	sPainter.setLineWidth(1.f * sPainter.getProjector()->getScreenScale());
 
 	StelCore *core=StelApp::getInstance().getCore();
-	Vec3d vel=core->getCurrentPlanet()->getHeliocentricEclipticVelocity();
-	vel=StelCore::matVsop87ToJ2000*vel;
-	vel*=core->getAberrationFactor() * (AU/(86400.0*SPEED_OF_LIGHT));
+	const Vec3d vel = core->getAberrationVec(core->getJDE());
 
 	// Show outlines
 	if (segments>0 && flagUseOutlines && oLim<=maxMagHints)
@@ -754,7 +754,7 @@ void Nebula::renderDarkNebulaMarker(StelPainter& sPainter, const float x, const
                                     float size, const Vec3f color) const
 {
 	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
-	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	const float scale = sPainter.getProjector()->getScreenScale();
 	size *= scale;
 
 	const float roundRadius = 0.35 * size;
@@ -841,7 +841,7 @@ void Nebula::renderMarkerRoundedRect(StelPainter& sPainter, const float x, const
                                      float size, const Vec3f color) const
 {
 	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
-	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	const float scale = sPainter.getProjector()->getScreenScale();
 	size *= scale;
 
 	const float roundRadius = 0.35 * size;
@@ -897,7 +897,7 @@ void Nebula::renderRoundMarker(StelPainter& sPainter, const float x, const float
                                float size, const Vec3f color, const bool crossed) const
 {
 	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
-	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	const float scale = sPainter.getProjector()->getScreenScale();
 	size *= scale;
 
 	sPainter.setBlending(true);
@@ -923,7 +923,7 @@ void Nebula::renderEllipticMarker(StelPainter& sPainter, const float x, const fl
                                   const float aspectRatio, const float angle, const Vec3f color) const
 {
 	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
-	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	const float scale = sPainter.getProjector()->getScreenScale();
 	size *= scale;
 
 	const float radiusY = 0.35 * size;
@@ -957,21 +957,21 @@ void Nebula::renderMarkerPointedCircle(StelPainter& sPainter, const float x, con
                                        float size, const Vec3f color, const bool insideRect) const
 {
 	// Take into account device pixel density and global scale ratio, as we are drawing 2D stuff.
-	const auto scale = sPainter.getProjector()->getDevicePixelsPerPixel();
+	const float scale = sPainter.getProjector()->getScreenScale();
 	size *= scale;
 
 	texPointElement->bind();
 	sPainter.setColor(color, hintsBrightness);
 	sPainter.setBlending(true, GL_SRC_ALPHA, GL_ONE);
-	const auto numPoints = StelUtils::getSmallerPowerOfTwo(std::clamp(int(0.4f*size), 8, 4096));
-	const auto spriteSize = std::min(0.25f * 2*M_PIf*size / numPoints, 5.f);
+	const auto numPoints = StelUtils::getSmallerPowerOfTwo(std::clamp(int(0.4f*size/scale), 8, 4096));
+	const auto spriteSize = std::min(0.25f * 2*M_PIf*size / numPoints, 5.f * scale);
 	if(insideRect)
 		size -= spriteSize*2;
 	const float*const cossin = StelUtils::ComputeCosSinRhoZone((2*M_PIf)/numPoints, numPoints, 0);
 	for(int n = 0; n < numPoints; ++n)
 	{
 		const auto cosa = cossin[2*n], sina = cossin[2*n+1];
-		sPainter.drawSprite2dMode(x - size*sina, y - size*cosa, spriteSize);
+		sPainter.drawSprite2dModeNoDeviceScale(x - size*sina, y - size*cosa, spriteSize);
 	}
 }
 
@@ -981,7 +981,12 @@ float Nebula::getHintSize(StelPainter& sPainter) const
 	float scaledSize = 0.0f;
 	// Should getPixelPerRadAtCenter() not adjust for HiDPI? Apparently it does not!
 	if (drawHintProportional)
-		scaledSize = static_cast<float>(getAngularRadius(Q_NULLPTR)) *(M_PI_180f)*static_cast<float>(sPainter.getProjector()->getPixelPerRadAtCenter()) / static_cast<float>(sPainter.getProjector()->getDevicePixelsPerPixel());
+	{
+		const float scale = sPainter.getProjector()->getScreenScale();
+		const float angularRadiusAtCenter = static_cast<float>(getAngularRadius(nullptr)) * M_PI_180f;
+		const float pixPerRadAtCenter = static_cast<float>(sPainter.getProjector()->getPixelPerRadAtCenter());
+		scaledSize = angularRadiusAtCenter * pixPerRadAtCenter / scale;
+	}
 	// TODO: Is it correct that for NebRegions any catalog data for getAngularRadius() is ignored? And that NebRegions are ALWAYS drawn with larger symbol?
 	if (nType==NebRegion)
 		scaledSize = 12.f;
@@ -1195,6 +1200,15 @@ void Nebula::readDSO(QDataStream &in)
 		>> Mel_nb >> PGC_nb >> UGC_nb >> Ced_nb >> Arp_nb >> VV_nb >> PK_nb >> PNG_nb >> SNRG_nb >> ACO_nb
 		>> HCG_nb >> ESO_nb >> VdBH_nb >> DWB_nb >> Tr_nb >> St_nb >> Ru_nb >> VdBHa_nb;
 
+	Ced_nb = Ced_nb.trimmed();
+	PK_nb = PK_nb.trimmed();
+	PNG_nb = PNG_nb.trimmed();
+	SNRG_nb = SNRG_nb.trimmed();
+	ACO_nb = ACO_nb.trimmed();
+	HCG_nb = HCG_nb.trimmed();
+	ESO_nb = ESO_nb.trimmed();
+	VdBH_nb = VdBH_nb.trimmed();
+
 	const unsigned int f = NGC_nb + IC_nb + M_nb + C_nb + B_nb + Sh2_nb + VdB_nb + RCW_nb + LDN_nb + LBN_nb + Cr_nb + Mel_nb + PGC_nb + UGC_nb + Arp_nb + VV_nb + DWB_nb + Tr_nb + St_nb + Ru_nb + VdBHa_nb;
 	if (f==0 && Ced_nb.isEmpty() && PK_nb.isEmpty() && PNG_nb.isEmpty() && SNRG_nb.isEmpty() && ACO_nb.isEmpty() && HCG_nb.isEmpty() && ESO_nb.isEmpty() && VdBH_nb.isEmpty())
 		withoutID = true;
@@ -1651,8 +1665,7 @@ Vec3d Nebula::getJ2000EquatorialPos(const StelCore* core) const
 		Vec3d pos=XYZ;
 		Q_ASSERT_X(fabs(pos.normSquared()-1.0)<0.0001, "Nebula aberration", "vertex length not unity");
 		//pos.normalize(); // Yay - not required!
-		Vec3d vel=core->getCurrentPlanet()->getHeliocentricEclipticVelocity();
-		vel=StelCore::matVsop87ToJ2000*vel*core->getAberrationFactor()*(AU/(86400.0*SPEED_OF_LIGHT));
+		Vec3d vel=core->getAberrationVec(core->getJDE());
 		pos+=vel;
 		pos.normalize();
 		return pos;
