@@ -42,10 +42,6 @@ typedef void (*posFuncType)(double, double*, double*, void*);
 
 typedef void (OsculatingFunctType)(double jde0,double jde,double xyz[3], double xyzdot[3]);
 
-// epoch J2000: 12 UT on 1 Jan 2000
-#define J2000 2451545.0
-#define ORBIT_SEGMENTS 360
-
 class Orbit;
 class KeplerOrbit;
 class StelFont;
@@ -149,6 +145,9 @@ public:
 	};
 	Q_ENUM(PositionQuality)
 
+	// epoch J2000: 12 UT on 1 Jan 2000
+	static inline constexpr double J2000 = 2451545.0;
+
 public:
 	Planet(const QString& englishName,
 	       double equatorialRadius,
@@ -394,10 +393,12 @@ public:
 	double getRotObliquity(double JDE) const;
 
 	//! Compute the position and orbital velocity in the parent Planet coordinate system and set aberrationPush
+	//! In case of the Sun, it is the heliocentric position and velocity so zeros are set
 	//! Does not compute new position when dateJDE is less than deltaJDE away from lastJDE
 	//! You can add the aberrationPush value according to Edot*lightTime in Explanatory Supplement (2013) formula 7.55.
 	virtual void computePosition(const StelObserver *observer, const double dateJDE, const Vec3d &aberrationPush);
 	//! Compute the position and orbital velocity in the parent Planet coordinate system, and return them in eclPosition and eclVelocity
+	//! In case of the Sun, it is the heliocentric position and velocity so zeros are set
 	//! These may be preferred when we want to avoid setting the actual position (e.g., RTS computation)
 	virtual void computePosition(const double dateJDE, Vec3d &eclPosition, Vec3d &eclVelocity) const;
 
@@ -476,6 +477,9 @@ public:
 	Vec3d getHeliocentricEclipticPos() const {return getHeliocentricPos(eclipticPos);}
 	Vec3d getHeliocentricEclipticPos(double dateJDE) const;
 
+	//! Return the barycentric ecliptical position
+	Vec3d getBarycentricEclipticPos(double dateJDE) const;
+
 	//! Return the heliocentric transformation for local (parentocentric) coordinate
 	//! @arg p planetocentric rectangular ecliptical coordinate (J2000)
 	//! @return heliocentric rectangular ecliptical coordinates (J2000)
@@ -487,9 +491,12 @@ public:
 	//! Get the planet velocity around the parent planet in ecliptical coordinates in AU/d
 	Vec3d getEclipticVelocity() const {return eclipticVelocity;}
 
-	//! Get the planet's heliocentric velocity in the solar system in ecliptical coordinates in AU/d. Required for aberration!
+	//! Get the planet's heliocentric velocity in the solar system in ecliptical coordinates in AU/d.
 	Vec3d getHeliocentricEclipticVelocity() const;
 
+	//! Return the barycentric ecliptical velocity in the solar system in ecliptical coordinates in AU/d. Required for aberration!
+	Vec3d getBarycentricEclipticVelocity(double dateJDE) const;
+
 	//! Compute and return the distance to the given position in heliocentric ecliptical (J2000) coordinates (in AU)
 	//! Preserves result for later retrieval by getDistance()
 	//! As side effect, improve fps by juggling update frequency (deltaJDE) for asteroids and other minor bodies. They must be fast if close to observer, but can be slow if further away.
@@ -528,6 +535,8 @@ public:
 	LinearFader orbitFader;
 	// draw orbital path of Planet
 	void drawOrbit(const StelCore*);
+
+	static constexpr int ORBIT_SEGMENTS = 360;
 	Vec3d orbit[ORBIT_SEGMENTS+1];  // store heliocentric coordinates for drawing the orbit
 	double deltaJDE;                // time difference between positional updates.
 	double deltaOrbitJDE;
@@ -786,6 +795,8 @@ protected:
 	QString objModelPath;
 
 	HipsSurveyP survey;
+	HipsSurveyP surveyForNormals;
+	HipsSurveyP surveyForHorizons;
 
 	Ring* rings;                     // Planet rings
 	double distance;                 // Temporary variable used to store the distance to a given point
@@ -879,6 +890,8 @@ private:
 		int eclipsePush; // apparent brightness push for partial Lunar Eclipse (make bright rim overbright)
 		int normalMap;
 		int horizonMap;
+		int hasNormalMap;
+		int hasHorizonMap;
 
 		// Rings-specific variables
 		int isRing;
@@ -906,7 +919,8 @@ private:
 	};
 
 	//! Calculates and uploads the common shader uniforms (projection matrix, texture, lighting&shadow data)
-	RenderData setCommonShaderUniforms(const StelPainter &painter, QOpenGLShaderProgram* shader, const PlanetShaderVars& shaderVars); // const;
+	RenderData setCommonShaderUniforms(const StelPainter &painter, QOpenGLShaderProgram* shader,
+	                                   const PlanetShaderVars& shaderVars, bool hasNormalMap, bool hasHorizonMap);
 
 	static PlanetShaderVars planetShaderVars;
 	static QOpenGLShaderProgram* planetShaderProgram;
