@@ -29,6 +29,7 @@
 
 class StelObject;
 class StelToneReproducer;
+class StelSkyCulture;
 class StelProjector;
 class StelPainter;
 class QSettings;
@@ -36,7 +37,7 @@ class QSettings;
 class ZoneArray;
 struct HipIndexStruct;
 
-static const int RCMAG_TABLE_SIZE = 4096;
+static const int RCMAG_TABLE_SIZE = 512;
 
 typedef struct
 {
@@ -69,7 +70,30 @@ typedef struct
 } crossid;
 
 typedef QMap<StelObjectP, float> StelACStarData;
-typedef QPair<float, float> PMData;
+typedef uint64_t StarId;
+
+typedef struct
+{
+	StarId hip;
+	bool primary;
+	double binary_period;
+	float eccentricity;
+	float inclination;
+	float big_omega;
+	float small_omega;
+	double periastron_epoch;
+	double semi_major;
+	double bary_distance;
+	double data_epoch;
+	double bary_ra;
+	double bary_dec;
+	double bary_rv;
+	double bary_pmra;
+	double bary_pmdec;
+	float primary_mass;
+	float secondary_mass;
+} binaryorbitstar;
+
 
 //! @class StarMgr
 //! Stores the star catalogue data.
@@ -250,146 +274,156 @@ public:
 	//! one was not found.
 	StelObjectP searchHP(int hip) const;
 
+	//! Search by Gaia source id.
+	//! @param source_id the Gaia source id of the star which is required.
+	//! @return the requested StelObjectP or an empty objecy if the requested
+	//! one was not found.
+	StelObjectP searchGaia(StarId source_id) const;
+
 	//! Get the (translated) common name for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated common name of star
-	static QString getCommonName(int hip);
+	static QString getCommonName(StarId hip);
 
 	//! Get the (translated) scientific name for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated scientific name of star
-	static QString getSciName(int hip);
+	static QString getSciName(StarId hip);
 
 	//! Get the (translated) scientific extra name for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated scientific name of star
-	static QString getSciExtraName(int hip);
+	static QString getSciExtraName(StarId hip);
 
 	//! Get the (translated) scientific name for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated scientific name of variable star
-	static QString getGcvsName(int hip);
+	static QString getGcvsName(StarId hip);
 
 	//! Get the (translated) scientific name for a double star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated scientific name of double star
-	static QString getWdsName(int hip);
+	static QString getWdsName(StarId hip);
 
 	//! Get the (English) common name for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return common name of star (from skyculture file star_names.fab)
-	static QString getCommonEnglishName(int hip);
+	static QString getCommonEnglishName(StarId hip);
 
 	//! Get the (translated) additional names for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return translated additional names of star
-	static QString getAdditionalNames(int hip);
+	static QString getAdditionalNames(StarId hip);
 
 	//! Get the English additional names for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return additional names of star
-	static QString getAdditionalEnglishNames(int hip);
+	static QString getAdditionalEnglishNames(StarId hip);
 
 	//! Get the cross-identification designations for a star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return cross-identification data
 	static QString getCrossIdentificationDesignations(QString hip);
 
 	//! Get the type of variability for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return type of variability
-	static QString getGcvsVariabilityType(int hip);
+	static QString getGcvsVariabilityType(StarId hip);
 
 	//! Get the magnitude at maximum brightness for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return the magnitude at maximum brightness for a variable star
-	static float getGcvsMaxMagnitude(int hip);
+	static float getGcvsMaxMagnitude(StarId hip);
 
 	//! Get the magnitude flag code for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return the magnitude flag code for a variable star
-	static int getGcvsMagnitudeFlag(int hip);
+	static int getGcvsMagnitudeFlag(StarId hip);
 
 	//! Get the minimum magnitude or amplitude for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @param firstMinimumFlag
 	//! @return the minimum magnitude or amplitude for a variable star
-	static float getGcvsMinMagnitude(int hip, bool firstMinimumFlag=true);
+	static float getGcvsMinMagnitude(StarId hip, bool firstMinimumFlag=true);
 
 	//! Get the photometric system for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return the photometric system for a variable star
-	static QString getGcvsPhotometricSystem(int hip);
+	static QString getGcvsPhotometricSystem(StarId hip);
 
 	//! Get Epoch for maximum light for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return Epoch for maximum light for a variable star
-	static double getGcvsEpoch(int hip);
+	static double getGcvsEpoch(StarId hip);
 
 	//! Get the period for a variable star with a specified
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return the period of variable star
-	static double getGcvsPeriod(int hip);
+	static double getGcvsPeriod(StarId hip);
 
 	//! Get the rising time or duration of eclipse for a variable star with a
-	//! specified Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! specified Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return the rising time or duration of eclipse for variable star
-	static int getGcvsMM(int hip);
+	static int getGcvsMM(StarId hip);
+
+	//! Get the spectral type of variable star with a
+	//! specified Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
+	//! @return the spectral type of variable star
+	static QString getGcvsSpectralType(StarId hip);
 
 	//! Get year of last satisfactory observation of double star with a
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return year of last satisfactory observation
-	static int getWdsLastObservation(int hip);
+	static int getWdsLastObservation(StarId hip);
 
 	//! Get position angle at date of last satisfactory observation of double star with a
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return position angle in degrees
-	static float getWdsLastPositionAngle(int hip);
+	static float getWdsLastPositionAngle(StarId hip);
 
 	//! Get separation angle at date of last satisfactory observation of double star with a
-	//! Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
+	//! Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
 	//! @return separation in arcseconds
-	static float getWdsLastSeparation(int hip);
+	static float getWdsLastSeparation(StarId hip);
 
-	//! Get the parallax error for star with a Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
-	//! @return the parallax error (mas)
-	static float getPlxError(int hip);
-
-	//! Get the proper motion data for star with a Hipparcos catalogue number.
-	//! @param hip The Hipparcos number of star
-	//! @return the proper motion (mas/yr for RA and Dec)
-	static PMData getProperMotion(int hip);
+	//! Get binary orbit data for a star with a specified Hipparcos or Gaia catalogue number.
+	//! @param hip The Hipparcos/Gaia number of star
+	//! @return binary orbit data
+	static binaryorbitstar getBinaryOrbitData(StarId hip);
 
 	static QString convertToSpectralType(int index);
 	static QString convertToComponentIds(int index);
+	static QString convertToOjectTypes(int index);
 
 	QVariantList getCatalogsDescription() const {return catalogsDescription;}
 
 	//! Try to load the given catalog, even if it is marched as unchecked.
 	//! Mark it as checked if checksum is correct.
+	//! @param m the catalog data.
+	//! @param load true if the catalog should be loaded, otherwise just check but don't load.
 	//! @return false in case of failure.
-	bool checkAndLoadCatalog(const QVariantMap& m);
+	bool checkAndLoadCatalog(const QVariantMap& m, bool load);
 
 	//! Get the list of all Hipparcos stars.
 	const QList<StelObjectP>& getHipparcosStars() const { return hipparcosStars; }	
@@ -407,8 +441,7 @@ private slots:
 
 	//! Called when the sky culture is updated.
 	//! Loads common and scientific names of stars for a given sky culture.
-	//! @param skyCultureDir the name of the directory containing the sky culture to use.
-	void updateSkyCulture(const QString& skyCultureDir);
+	void updateSkyCulture(const StelSkyCulture& skyCulture);
 
 	//! increase artificial cutoff magnitude slightly (can be linked to an action/hotkey)
 	void increaseStarsMagnitudeLimit();
@@ -430,11 +463,22 @@ private:
 
 	void copyDefaultConfigFile();
 
+	struct CommonNames
+	{
+		QHash<int, QString> byHIP;
+		QMap<QString, int> hipByName;
+	};
 	//! Loads common names for stars from a file.
 	//! Called when the SkyCulture is updated.
 	//! @param the path to a file containing the common names for bright stars.
 	//! @note Stellarium doesn't support sky cultures made prior version 0.10.6 now!
-	int loadCommonNames(const QString& commonNameFile);
+	CommonNames loadCommonNames(const QString& commonNameFile) const;
+
+	//! Load culture-specific names for stars from JSON data
+	void loadCultureSpecificNames(const QJsonObject& data, const QMap<QString, int>& commonNamesIndexToSearchWhileLoading);
+	void loadCultureSpecificNameForStar(const QJsonArray& data, StarId HIP);
+	void loadCultureSpecificNameForNamedObject(const QJsonArray& data, const QString& commonName,
+	                                           const QMap<QString, int>& commonNamesIndexToSearchWhileLoading);
 
 	//! Loads scientific names for stars from a file.
 	//! Called when the SkyCulture is updated.
@@ -454,13 +498,9 @@ private:
 	//! @param the path to a file containing the cross-identification data.
 	void loadCrossIdentificationData(const QString& crossIdFile);
 
-	//! Loads parallax error data from a file.
-	//! @param the path to a file containing the parallax error data.
-	void loadPlxErr(const QString& plxErrFile);
-
-	//! Loads proper motion data from a file.
-	//! @param the path to a file containing the proper motion data.
-	void loadPMData(const QString& pmDataFile);
+	//! Loads orbital parameters data for binary systems data from a file.
+	//! @param the path to a file containing the orbital parameters data for binary systems.
+	void loadBinaryOrbitalData(const QString& orbitalParamFile);
 
 	//! Gets the maximum search level.
 	// TODO: add a non-lame description - what is the purpose of the max search level?
@@ -507,36 +547,35 @@ private:
 
 	HipIndexStruct *hipIndex; // array of Hipparcos stars
 
-	static QHash<int, QString> commonNamesMap;     // the original names from skyculture (star_names.fab)
-	static QHash<int, QString> commonNamesMapI18n; // translated names
-	static QMap<QString, int> commonNamesIndexI18n;
-	static QMap<QString, int> commonNamesIndex;
+	static QHash<StarId, QString> commonNamesMap;     // the original names from skyculture (star_names.fab)
+	static QHash<StarId, QString> commonNamesMapI18n; // translated names
+	static QMap<QString, StarId> commonNamesIndexI18n;
+	static QMap<QString, StarId> commonNamesIndex;
 
-	static QHash<int, QString> additionalNamesMap; // additional names
-	static QHash<int, QString> additionalNamesMapI18n;
-	static QMap<QString, int> additionalNamesIndex;
-	static QMap<QString, int> additionalNamesIndexI18n;
+	static QHash<StarId, QString> additionalNamesMap; // additional names
+	static QHash<StarId, QString> additionalNamesMapI18n;
+	static QMap<QString, StarId> additionalNamesIndex;
+	static QMap<QString, StarId> additionalNamesIndexI18n;
 
-	static QHash<int, QString> sciDesignationsMapI18n;
-	static QMap<QString, int> sciDesignationsIndexI18n;
-	static QHash<int, QString> sciExtraDesignationsMapI18n;
-	static QMap<QString, int> sciExtraDesignationsIndexI18n;
+	static QHash<StarId, QString> sciDesignationsMapI18n;
+	static QMap<QString, StarId> sciDesignationsIndexI18n;
+	static QHash<StarId, QString> sciExtraDesignationsMapI18n;
+	static QMap<QString, StarId> sciExtraDesignationsIndexI18n;
 
-	static QHash<int, varstar> varStarsMapI18n;
-	static QMap<QString, int> varStarsIndexI18n;
+	static QHash<StarId, varstar> varStarsMapI18n;
+	static QMap<QString, StarId> varStarsIndexI18n;
 
-	static QHash<int, wds> wdsStarsMapI18n;
-	static QMap<QString, int> wdsStarsIndexI18n;
+	static QHash<StarId, wds> wdsStarsMapI18n;
+	static QMap<QString, StarId> wdsStarsIndexI18n;
 
 	static QMap<QString, crossid> crossIdMap;
-	static QMap<int, int> saoStarsIndex;
-	static QMap<int, int> hdStarsIndex;
-	static QMap<int, int> hrStarsIndex;
+	static QHash<int, StarId> saoStarsIndex;
+	static QHash<int, StarId> hdStarsIndex;
+	static QHash<int, StarId> hrStarsIndex;
 
-	static QHash<int, float> hipParallaxErrors;
-	static QHash<int, PMData> hipPMData;
+	static QHash<StarId, QString> referenceMap;
 
-	static QHash<int, QString> referenceMap;
+	static QHash<StarId, binaryorbitstar> binaryOrbitStarMap;
 
 	QFont starFont;
 	static bool flagSciNames;
